@@ -3,7 +3,7 @@ use std::collections::HashMap;
 use crate::dns::{DnsPacketContent, Name};
 
 /// MINFO recors are used to acquire mailbox or mail list information
-#[derive(Debug, PartialEq, Eq, Hash)]
+#[derive(Debug, PartialEq, Eq, Hash, Clone)]
 pub struct MINFO<'a> {
     /// A [Name](`Name`) which specifies a mailbox which is responsible for the mailing list or mailbox.  
     pub rmailbox: Name<'a>,
@@ -12,6 +12,16 @@ pub struct MINFO<'a> {
     pub emailbox: Name<'a>,
 }
 
+impl<'a> MINFO<'a> {
+    /// Transforms the inner data into it's owned type
+    pub fn into_owned<'b>(self) -> MINFO<'b> {
+        MINFO {
+            rmailbox: self.rmailbox.into_owned(),
+            emailbox: self.emailbox.into_owned(),
+        }
+    }
+}
+
 impl<'a> DnsPacketContent<'a> for MINFO<'a> {
     fn parse(data: &'a [u8], position: usize) -> crate::Result<Self>
     where
